[Libreoffice-commits] core.git: sc/source

Johnny_M klasse at partyheld.de
Mon Feb 12 09:50:41 UTC 2018


 sc/source/filter/excel/excform8.cxx |   18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

New commits:
commit ee47b7b4c805fc781dab48c65c4ff5fc701b3709
Author: Johnny_M <klasse at partyheld.de>
Date:   Sat Feb 10 13:46:33 2018 +0100

    Translate German variable names
    
    Fakt -> Factor in Excel filter (excform8)
    
    Change-Id: Ic63dc819d6b3b5fb5f8c362a72b6d5844dce2c11
    Reviewed-on: https://gerrit.libreoffice.org/49530
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Michael Stahl <mstahl at redhat.com>

diff --git a/sc/source/filter/excel/excform8.cxx b/sc/source/filter/excel/excform8.cxx
index db501e8c87a4..ccd2211a275e 100644
--- a/sc/source/filter/excel/excform8.cxx
+++ b/sc/source/filter/excel/excform8.cxx
@@ -375,18 +375,18 @@ ConvErr ExcelToSc8::Convert( const ScTokenArray*& rpTokArray, XclImpStream& aIn,
                 break;
             case 0x19: // Special Attribute                     [327 279]
             {
-                sal_uInt16 nData(0), nFakt(0);
+                sal_uInt16 nData(0), nFactor(0);
                 sal_uInt8 nOpt(0);
 
                 nOpt = aIn.ReaduInt8();
                 nData = aIn.ReaduInt16();
-                nFakt = 2;
+                nFactor = 2;
 
                 if( nOpt & 0x04 )
                 {
                     // nFakt -> skip bytes or words    AttrChoose
                     nData++;
-                    aIn.Ignore(static_cast<std::size_t>(nData) * nFakt);
+                    aIn.Ignore(static_cast<std::size_t>(nData) * nFactor);
                 }
                 else if( nOpt & 0x10 )                      // AttrSum
                     DoMulArgs( ocSum, 1 );
@@ -1023,18 +1023,18 @@ ConvErr ExcelToSc8::Convert( ScRangeListTabs& rRangeList, XclImpStream& aIn, std
                 break;
             case 0x19: // Special Attribute                     [327 279]
             {
-                sal_uInt16 nData(0), nFakt(0);
+                sal_uInt16 nData(0), nFactor(0);
                 sal_uInt8 nOpt(0);
 
                 nOpt = aIn.ReaduInt8();
                 nData = aIn.ReaduInt16();
-                nFakt = 2;
+                nFactor = 2;
 
                 if( nOpt & 0x04 )
                 {
                     // nFakt -> skip bytes or words    AttrChoose
                     ++nData;
-                    aIn.Ignore(static_cast<std::size_t>(nData) * nFakt);
+                    aIn.Ignore(static_cast<std::size_t>(nData) * nFactor);
                 }
             }
                 break;
@@ -1668,7 +1668,7 @@ void ExcelToSc8::GetAbsRefs( ScRangeList& r, XclImpStream& aIn, std::size_t nLen
                 nOpt = aIn.ReaduInt8();
                 nData = aIn.ReaduInt16();
                 if( nOpt & 0x04 )
-                {// nFakt -> skip bytes or words    AttrChoose
+                {// nFactor -> skip bytes or words    AttrChoose
                     nData++;
                     nSeek = nData * 2;
             }
@@ -375,18 +375,18 @@ ConvErr ExcelToSc8::Convert( const ScTokenArray*& rpTokArray, XclImpStream& aIn,
                 if( nOpt & 0x04 )
                 {
-                    // nFakt -> skip bytes or words    AttrChoose
+                    // nFactor -> skip bytes or words    AttrChoose
                     nData++;
@@ -1023,18 +1023,18 @@ ConvErr ExcelToSc8::Convert( ScRangeListTabs& rRangeList, XclImpStream& aIn, std
                 if( nOpt & 0x04 )
                 {
-                    // nFakt -> skip bytes or words    AttrChoose
+                    // nFactor -> skip bytes or words    AttrChoose
                     ++nData;


More information about the Libreoffice-commits mailing list